pub struct CrosvmCmdlineArgs {
pub extended_status: bool,
pub log_level: String,
pub syslog_tag: Option<String>,
pub no_syslog: bool,
pub command: Command,
}Expand description
crosvm
Fields
extended_status: booluse extended exit status
log_level: Stringspecify log level, eg “off”, “error”, “debug,disk=off”, etc
syslog_tag: Option<String>when logging to syslog, use the provided tag
no_syslog: booldisable output to syslog
command: CommandTrait Implementations
Sourceimpl FromArgs for CrosvmCmdlineArgs
impl FromArgs for CrosvmCmdlineArgs
Sourcefn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
fn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
Construct the type from an input set of arguments. Read more
Sourcefn redact_arg_values(
__cmd_name: &[&str],
__args: &[&str],
) -> Result<Vec<String>, EarlyExit>
fn redact_arg_values( __cmd_name: &[&str], __args: &[&str], ) -> Result<Vec<String>, EarlyExit>
Get a String with just the argument names, e.g., options, flags, subcommands, etc, but
without the values of the options and arguments. This can be useful as a means to capture
anonymous usage statistics without revealing the content entered by the end user. Read more
impl TopLevelCommand for CrosvmCmdlineArgs