Struct DiskOptionWithId

struct DiskOptionWithId {
    disk_option: DiskOption,
    index: usize,
}
Structure containing the parameters for a single disk as well as a unique counter increasing each time a new disk parameter is parsed.

This allows the letters assigned to each disk to reflect the order of their declaration, as we have several options for specifying disks (rwroot, root, etc) and order can thus be lost when they are aggregated.

Fields

disk_option: DiskOptionindex: usize