pub struct UsbCommand {
pub command: UsbSubCommand,
}Expand description
Manage attached virtual USB devices.
Fields
command: UsbSubCommandTrait Implementations
Sourceimpl FromArgs for UsbCommand
impl FromArgs for UsbCommand
Sourcefn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
fn from_args(__cmd_name: &[&str], __args: &[&str]) -> Result<Self, EarlyExit>
Construct the type from an input set of arguments. Read more
Sourcefn redact_arg_values(
__cmd_name: &[&str],
__args: &[&str],
) -> Result<Vec<String>, EarlyExit>
fn redact_arg_values( __cmd_name: &[&str], __args: &[&str], ) -> Result<Vec<String>, EarlyExit>
Get a String with just the argument names, e.g., options, flags, subcommands, etc, but
without the values of the options and arguments. This can be useful as a means to capture
anonymous usage statistics without revealing the content entered by the end user. Read more