pub fn parse_touch_device_option(s: &str) -> Result<TouchDeviceOption, String>Expand description
Parse virtio-input touch device options from a string.
This function only exists to enable the use of the deprecated colon-separated form
(“PATH:WIDTH:HEIGHT:NAME”); once the deprecation period is over, this function should be removed
in favor of using the derived FromKeyValues function directly.