pub struct SharedVcpuState {
ioport_regions: BTreeSet<Range>,
mmio_regions: BTreeSet<Range>,
hint: Option<CallHint>,
}Expand description
State shared by every VCPU, grouped together to make edits to the state coherent across VCPUs.
Fields
ioport_regions: BTreeSet<Range>mmio_regions: BTreeSet<Range>hint: Option<CallHint>Implementations
sourcepub fn reserve_range(
&mut self,
space: IoSpace,
start: u64,
length: u64,
async_write: bool,
) -> SysResult<()>
pub fn reserve_range( &mut self, space: IoSpace, start: u64, length: u64, async_write: bool, ) -> SysResult<()>
Reserves the given range for handling by the plugin process.
This will reject any reservation that overlaps with an existing reservation.
pub fn unreserve_range(&mut self, space: IoSpace, start: u64) -> SysResult<()>
pub fn set_hint( &mut self, space: IoSpace, addr: u64, on_write: bool, regs: Vec<CallHintDetails>, )
fn is_reserved(&self, space: IoSpace, addr: u64) -> bool
fn first_before(&self, io_space: IoSpace, addr: u64) -> Option<Range>
fn matches_hint(&self, io_space: IoSpace, addr: u64, is_write: bool) -> bool
fn check_hint_details(&self, regs: &kvm_regs) -> (bool, bool)