pub struct DevicesCommand {
pub async_executor: Option<ExecutorKind>,
pub disable_sandbox: bool,
pub jail: JailConfig,
pub serial: Vec<VhostUserParams<SerialParameters>>,
pub block: Vec<VhostUserParams<DiskOption>>,
pub vsock: Vec<VhostUserParams<VsockConfig>>,
pub net: Vec<VhostUserParams<NetParameters>>,
pub control_socket: Option<PathBuf>,
}Expand description
Start one or several jailed device processes.
Fields
async_executor: Option<ExecutorKind>configure async executor backend to “uring” or “epoll” (default).
disable_sandbox: booldisable sandboxing. Will nullify the –jail option if it was present.
jail: JailConfigset up the jail configuration.
Possible key values:
pivot-root=/path - Path to empty directory to use for
sandbox pivot root.
seccomp-policy-dir=/path - Path to seccomp .policy files
seccomp-log-failures=(true|false) - Log seccomp filter
failures instead of them being fatal.
serial: Vec<VhostUserParams<SerialParameters>>start a serial device.
Possible key values:
vhost=PATH - Path to a vhost-user socket to listen to.
This parameter must be given in first position.
type=(stdout,syslog,sink,file) - Where to route the
serial device
hardware=(serial,virtio-console) - Which type of serial
hardware to emulate. Defaults to 8250 UART (serial).
num=(1,2,3,4) - Serial Device Number. If not provided,
num will default to 1.
path=PATH - The path to the file to write to when
type=file
input=PATH - The path to the file to read from when not
stdin
console - Use this serial device as the guest console.
Can only be given once. Will default to first
serial port if not provided.
earlycon - Use this serial device as the early console.
Can only be given once.
stdin - Direct standard input to this serial device.
Can only be given once. Will default to first serial
port if not provided.
pci-address - Preferred PCI address, e.g. “00:01.0”.
Only applies to virtio-console hardware type.
block: Vec<VhostUserParams<DiskOption>>start a block device.
Possible key values:
vhost=PATH - Path to a vhost-user socket to listen to.
This parameter must be given in first position.
block options:
See help from crosvm run command.
vsock: Vec<VhostUserParams<VsockConfig>>start a vsock device.
Possible key values:
vhost=PATH - Path to a vhost-user socket to listen to.
This parameter must be given in first position.
cid=CID - CID to use for the device.
device=VHOST_DEVICE - path to the vhost-vsock device to
use (Linux only). Defaults to /dev/vhost-vsock.
net: Vec<VhostUserParams<NetParameters>>start a network device.
Possible key values:
vhost=PATH - Path to a vhost-user socket to listen to.
This parameter must be given in first position.
network options:
See help from the crosvm run command.
control_socket: Option<PathBuf>path to put the control socket.