pub struct ScsiConfig<'a>(pub &'a [ScsiOption]);Tuple Fields
0: &'a [ScsiOption]Trait Implementations
Sourceimpl<'a> VirtioDeviceBuilder for &'a ScsiConfig<'a>
impl<'a> VirtioDeviceBuilder for &'a ScsiConfig<'a>
Sourcefn create_virtio_device(
self,
protection_type: ProtectionType,
) -> Result<Box<dyn VirtioDevice>>
fn create_virtio_device( self, protection_type: ProtectionType, ) -> Result<Box<dyn VirtioDevice>>
Create a regular virtio device from the configuration and
protection_type setting.Sourcefn create_vhost_user_device(
self,
_keep_rds: &mut Vec<RawDescriptor>,
) -> Result<Box<dyn VhostUserDeviceBuilder>>
fn create_vhost_user_device( self, _keep_rds: &mut Vec<RawDescriptor>, ) -> Result<Box<dyn VhostUserDeviceBuilder>>
Create a device suitable for being run as a vhost-user instance. Read more
Sourcefn create_jail(
&self,
jail_config: Option<&JailConfig>,
virtio_transport: VirtioDeviceType,
) -> Result<Option<Minijail>>
fn create_jail( &self, jail_config: Option<&JailConfig>, virtio_transport: VirtioDeviceType, ) -> Result<Option<Minijail>>
Create a jail that is suitable to run a device. Read more
Sourcefn create_virtio_device_and_jail(
self,
protection_type: ProtectionType,
jail_config: Option<&JailConfig>,
) -> Result<VirtioDeviceStub>
fn create_virtio_device_and_jail( self, protection_type: ProtectionType, jail_config: Option<&JailConfig>, ) -> Result<VirtioDeviceStub>
Helper method to return a
VirtioDeviceStub filled using create_virtio_device and
create_jail. Read moreAuto Trait Implementations
impl<'a> Freeze for ScsiConfig<'a>
impl<'a> RefUnwindSafe for ScsiConfig<'a>
impl<'a> Send for ScsiConfig<'a>
impl<'a> Sync for ScsiConfig<'a>
impl<'a> Unpin for ScsiConfig<'a>
impl<'a> UnwindSafe for ScsiConfig<'a>