Struct PortKey

struct PortKey {
    port_state: PortState,
    pci_address: PciAddress,
}
PortKey is a unique identifier of ports with an ordering defined on it.

Ports are ordered by whose downstream device would be discovered first by the guest OS. Empty ports without pending events are ordered before those with pending events. When multiple empty ports without pending events are available, they are ordered by PCI enumeration.

Fields

port_state: PortStatepci_address: PciAddress