struct DiskOptionWithId {
disk_option: DiskOption,
index: usize,
}Expand description
Structure containing the parameters for a single disk as well as a unique counter increasing each time a new disk parameter is parsed.
This allows the letters assigned to each disk to reflect the order of their declaration, as we have several options for specifying disks (rwroot, root, etc) and order can thus be lost when they are aggregated.
Fields
disk_option: DiskOptionindex: usizeTrait Implementations
Sourceimpl Clone for DiskOptionWithId
impl Clone for DiskOptionWithId
Sourcefn clone(&self) -> DiskOptionWithId
fn clone(&self) -> DiskOptionWithId
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiskOptionWithId
impl Debug for DiskOptionWithId
Sourceimpl From<DiskOption> for DiskOptionWithId
Assign the next id to disk_option.
impl From<DiskOption> for DiskOptionWithId
Assign the next id to disk_option.
Sourcefn from(disk_option: DiskOption) -> Self
fn from(disk_option: DiskOption) -> Self
Converts to this type from the input type.
Sourceimpl From<DiskOptionWithId> for DiskOption
impl From<DiskOptionWithId> for DiskOption
Sourcefn from(disk_option_with_id: DiskOptionWithId) -> Self
fn from(disk_option_with_id: DiskOptionWithId) -> Self
Converts to this type from the input type.