pub struct PmemOption {
pub path: PathBuf,
pub ro: bool,
pub root: bool,
pub vma_size: Option<u64>,
pub swap_interval: Option<Duration>,
}Fields
path: PathBufPath to the diks image.
ro: boolWhether the disk is read-only.
root: boolIf set, add a kernel command line option making this the root device. Can only be set once.
vma_size: Option<u64>Experimental option to specify the size in bytes of an anonymous virtual memory area that will be created to back this device.
swap_interval: Option<Duration>Experimental option to specify interval for periodic swap out of memory mapping